==> paraview_5.1.2+dfsg1.orig.tar.xz: ParaView-v5.1.2/Qt/ApplicationComponents/pqPluginDocumentationBehavior.h <==
/*=========================================================================

   Program: ParaView
   Module:    $RCSfile$

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2. 
   
   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqPluginDocumentationBehavior_h
#define pqPluginDocumentationBehavior_h

#include <QObject>
#include "pqApplicationComponentsModule.h"

class QHelpEngine;
class vtkPVPlugin;

/// @ingroup Behaviors
/// pqPluginDocumentationBehavior is a helper class that ensures that
/// documentation from plugins is registered with the QHelpEngine.
class PQAPPLICATIONCOMPONENTS_EXPORT pqPluginDocumentationBehavior : public QObject
{
  Q_OBJECT
  typedef QObject Superclass;
public:
  pqPluginDocumentationBehavior(QHelpEngine* engine);
  virtual ~pqPluginDocumentationBehavior();

protected slots:
  void updatePlugin(vtkPVPlugin*);
  void updatePlugins();
  void refreshHelpEngine();

private:
  Q_DISABLE_COPY(pqPluginDocumentationBehavior)

  class pqInternals;
  pqInternals* Internals;
};

#endif

==> paraview_5.4.1+dfsg3.orig.tar.xz: ParaView-v5.4.1/Qt/ApplicationComponents/pqPluginDocumentationBehavior.h <==
/*=========================================================================

   Program: ParaView
   Module:    $RCSfile$

   Copyright (c) 2005,2006 Sandia Corporation, Kitware Inc.
   All rights reserved.

   ParaView is a free software; you can redistribute it and/or modify it
   under the terms of the ParaView license version 1.2.

   See License_v1.2.txt for the full ParaView license.
   A copy of this license can be obtained by contacting
   Kitware Inc.
   28 Corporate Drive
   Clifton Park, NY 12065
   USA

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR
CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

========================================================================*/
#ifndef pqPluginDocumentationBehavior_h
#define pqPluginDocumentationBehavior_h

#include "pqApplicationComponentsModule.h"
#include <QObject>

class QHelpEngine;
class vtkPVPlugin;

/**
* @ingroup Behaviors
* pqPluginDocumentationBehavior is a helper class that ensures that
* documentation from plugins is registered with the QHelpEngine.
*/
class PQAPPLICATIONCOMPONENTS_EXPORT pqPluginDocumentationBehavior : public QObject
{
  Q_OBJECT
  typedef QObject Superclass;

public:
  pqPluginDocumentationBehavior(QHelpEngine* engine);
  virtual ~pqPluginDocumentationBehavior();

protected slots:
  void updatePlugin(vtkPVPlugin*);
  void updatePlugins();
  void refreshHelpEngine();

private:
  Q_DISABLE_COPY(pqPluginDocumentationBehavior)

  class pqInternals;
  pqInternals* Internals;
};

#endif
